package androidx.test.espresso.core.internal.deps.guava.collect;

import androidx.test.espresso.core.internal.deps.guava.base.Preconditions;
import androidx.test.espresso.core.internal.deps.guava.collect.ImmutableCollection;
import java.io.Serializable;
import java.util.Arrays;
import java.util.Set;
/* loaded from: classes3.dex */
public abstract class ImmutableSet<E> extends ImmutableCollection<E> implements Set<E> {
    private transient ImmutableList<E> asList;

    /* JADX INFO: Access modifiers changed from: private */
    public static boolean shouldTrim(int actualUnique, int expectedUnique) {
        return actualUnique < (expectedUnique >> 1) + (expectedUnique >> 2);
    }

    boolean isHashCodeFast() {
        return false;
    }

    @Override // androidx.test.espresso.core.internal.deps.guava.collect.ImmutableCollection, java.util.AbstractCollection, java.util.Collection, java.lang.Iterable
    public abstract UnmodifiableIterator<E> iterator();

    public static <E> ImmutableSet<E> of() {
        return RegularImmutableSet.EMPTY;
    }

    public static <E> ImmutableSet<E> of(E element) {
        return new SingletonImmutableSet(element);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static <E> ImmutableSet<E> construct(int n, Object... elements) {
        if (n != 0) {
            if (n == 1) {
                return of(elements[0]);
            }
            int chooseTableSize = chooseTableSize(n);
            Object[] objArr = new Object[chooseTableSize];
            int i = chooseTableSize - 1;
            int i2 = 0;
            int i3 = 0;
            for (int i4 = 0; i4 < n; i4++) {
                Object checkElementNotNull = ObjectArrays.checkElementNotNull(elements[i4], i4);
                int hashCode = checkElementNotNull.hashCode();
                int smear = Hashing.smear(hashCode);
                while (true) {
                    int i5 = smear & i;
                    Object obj = objArr[i5];
                    if (obj == null) {
                        elements[i3] = checkElementNotNull;
                        objArr[i5] = checkElementNotNull;
                        i2 += hashCode;
                        i3++;
                        break;
                    } else if (obj.equals(checkElementNotNull)) {
                        break;
                    } else {
                        smear++;
                    }
                }
            }
            Arrays.fill(elements, i3, n, (Object) null);
            if (i3 == 1) {
                return new SingletonImmutableSet(elements[0], i2);
            }
            if (chooseTableSize(i3) < chooseTableSize / 2) {
                return construct(i3, elements);
            }
            if (shouldTrim(i3, elements.length)) {
                elements = Arrays.copyOf(elements, i3);
            }
            return new RegularImmutableSet(elements, i2, objArr, i, i3);
        }
        return of();
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static int chooseTableSize(int setSize) {
        int max = Math.max(setSize, 2);
        if (max < 751619276) {
            int highestOneBit = Integer.highestOneBit(max - 1) << 1;
            while (highestOneBit * 0.7d < max) {
                highestOneBit <<= 1;
            }
            return highestOneBit;
        }
        Preconditions.checkArgument(max < 1073741824, "collection too large");
        return 1073741824;
    }

    public static <E> ImmutableSet<E> copyOf(E[] elements) {
        int length = elements.length;
        if (length != 0) {
            if (length == 1) {
                return of((Object) elements[0]);
            }
            return construct(elements.length, (Object[]) elements.clone());
        }
        return of();
    }

    @Override // java.util.Collection, java.util.Set
    public boolean equals(Object object) {
        if (object == this) {
            return true;
        }
        if ((object instanceof ImmutableSet) && isHashCodeFast() && ((ImmutableSet) object).isHashCodeFast() && hashCode() != object.hashCode()) {
            return false;
        }
        return Sets.equalsImpl(this, object);
    }

    @Override // java.util.Collection, java.util.Set
    public int hashCode() {
        return Sets.hashCodeImpl(this);
    }

    @Override // androidx.test.espresso.core.internal.deps.guava.collect.ImmutableCollection
    public ImmutableList<E> asList() {
        ImmutableList<E> immutableList = this.asList;
        if (immutableList == null) {
            ImmutableList<E> createAsList = createAsList();
            this.asList = createAsList;
            return createAsList;
        }
        return immutableList;
    }

    ImmutableList<E> createAsList() {
        return ImmutableList.asImmutableList(toArray());
    }

    /* loaded from: classes2.dex */
    private static class SerializedForm implements Serializable {
        private static final long serialVersionUID = 0;
        final Object[] elements;

        SerializedForm(Object[] elements) {
            this.elements = elements;
        }

        Object readResolve() {
            return ImmutableSet.copyOf(this.elements);
        }
    }

    @Override // androidx.test.espresso.core.internal.deps.guava.collect.ImmutableCollection
    Object writeReplace() {
        return new SerializedForm(toArray());
    }

    public static <E> Builder<E> builder() {
        return new Builder<>();
    }

    /* loaded from: classes4.dex */
    public static class Builder<E> extends ImmutableCollection.ArrayBasedBuilder<E> {
        private int hashCode;
        Object[] hashTable;

        /* JADX WARN: Multi-variable type inference failed */
        @Override // androidx.test.espresso.core.internal.deps.guava.collect.ImmutableCollection.ArrayBasedBuilder, androidx.test.espresso.core.internal.deps.guava.collect.ImmutableCollection.Builder
        public /* bridge */ /* synthetic */ ImmutableCollection.ArrayBasedBuilder add(Object element) {
            return add((Builder<E>) element);
        }

        /* JADX WARN: Multi-variable type inference failed */
        @Override // androidx.test.espresso.core.internal.deps.guava.collect.ImmutableCollection.ArrayBasedBuilder, androidx.test.espresso.core.internal.deps.guava.collect.ImmutableCollection.Builder
        public /* bridge */ /* synthetic */ ImmutableCollection.Builder add(Object element) {
            return add((Builder<E>) element);
        }

        public Builder() {
            super(4);
        }

        @Override // androidx.test.espresso.core.internal.deps.guava.collect.ImmutableCollection.ArrayBasedBuilder, androidx.test.espresso.core.internal.deps.guava.collect.ImmutableCollection.Builder
        public Builder<E> add(E element) {
            Preconditions.checkNotNull(element);
            if (this.hashTable != null && ImmutableSet.chooseTableSize(this.size) <= this.hashTable.length) {
                addDeduping(element);
                return this;
            }
            this.hashTable = null;
            super.add((Builder<E>) element);
            return this;
        }

        @Override // androidx.test.espresso.core.internal.deps.guava.collect.ImmutableCollection.ArrayBasedBuilder, androidx.test.espresso.core.internal.deps.guava.collect.ImmutableCollection.Builder
        public Builder<E> add(E... elements) {
            if (this.hashTable != null) {
                for (E e : elements) {
                    add((Builder<E>) e);
                }
            } else {
                super.add((Object[]) elements);
            }
            return this;
        }

        private void addDeduping(E element) {
            int length = this.hashTable.length - 1;
            int hashCode = element.hashCode();
            int smear = Hashing.smear(hashCode);
            while (true) {
                int i = smear & length;
                Object[] objArr = this.hashTable;
                Object obj = objArr[i];
                if (obj == null) {
                    objArr[i] = element;
                    this.hashCode += hashCode;
                    super.add((Builder<E>) element);
                    return;
                } else if (obj.equals(element)) {
                    return;
                } else {
                    smear = i + 1;
                }
            }
        }

        public ImmutableSet<E> build() {
            ImmutableSet<E> construct;
            int i = this.size;
            if (i != 0) {
                if (i == 1) {
                    return ImmutableSet.of(this.contents[0]);
                }
                if (this.hashTable == null || ImmutableSet.chooseTableSize(this.size) != this.hashTable.length) {
                    construct = ImmutableSet.construct(this.size, this.contents);
                    this.size = construct.size();
                } else {
                    Object[] copyOf = ImmutableSet.shouldTrim(this.size, this.contents.length) ? Arrays.copyOf(this.contents, this.size) : this.contents;
                    int i2 = this.hashCode;
                    Object[] objArr = this.hashTable;
                    construct = new RegularImmutableSet<>(copyOf, i2, objArr, objArr.length - 1, this.size);
                }
                this.forceCopy = true;
                this.hashTable = null;
                return construct;
            }
            return ImmutableSet.of();
        }
    }
}
