package androidx.test.internal.runner;

import java.util.ArrayList;
import org.junit.runner.Description;
import org.junit.runner.Runner;
import org.junit.runner.manipulation.Filter;
import org.junit.runner.manipulation.Filterable;
import org.junit.runner.manipulation.NoTestsRemainException;
import org.junit.runner.manipulation.Sortable;
import org.junit.runner.manipulation.Sorter;
import org.junit.runner.notification.RunNotifier;
/* loaded from: classes4.dex */
class NonExecutingRunner extends Runner implements Sortable, Filterable {
    private final Runner runner;

    /* JADX INFO: Access modifiers changed from: package-private */
    public NonExecutingRunner(Runner runner) {
        this.runner = runner;
    }

    @Override // org.junit.runner.Runner, org.junit.runner.Describable
    public Description getDescription() {
        return this.runner.getDescription();
    }

    @Override // org.junit.runner.Runner
    public void run(RunNotifier notifier) {
        generateListOfTests(notifier, getDescription());
    }

    @Override // org.junit.runner.manipulation.Filterable
    public void filter(Filter filter) throws NoTestsRemainException {
        filter.apply(this.runner);
    }

    @Override // org.junit.runner.manipulation.Sortable
    public void sort(Sorter sorter) {
        sorter.apply(this.runner);
    }

    private void generateListOfTests(RunNotifier runNotifier, Description description) {
        ArrayList<Description> children = description.getChildren();
        if (children.isEmpty()) {
            runNotifier.fireTestStarted(description);
            runNotifier.fireTestFinished(description);
            return;
        }
        for (Description description2 : children) {
            generateListOfTests(runNotifier, description2);
        }
    }
}
