package androidx.test.runner.permission;

import android.app.UiAutomation;
import android.os.ParcelFileDescriptor;
import android.util.Log;
import androidx.test.InstrumentationRegistry;
import androidx.test.internal.util.Checks;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.TimeoutException;
/* loaded from: classes3.dex */
class UiAutomationShellCommand extends ShellCommand {
    private static final String TAG = "UiAutomationShellCmd";
    private final PmCommand command;
    private final String permission;
    private final String targetPackage;
    private final UiAutomation uiAutomation = (UiAutomation) Checks.checkNotNull(InstrumentationRegistry.getInstrumentation().getUiAutomation());

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes2.dex */
    public enum PmCommand {
        GRANT_PERMISSION("grant");
        
        private final String pmCommand;

        PmCommand(String command) {
            String valueOf = String.valueOf(command);
            this.pmCommand = valueOf.length() != 0 ? "pm ".concat(valueOf) : new String("pm ");
        }

        public String get() {
            return this.pmCommand;
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public UiAutomationShellCommand(String targetPackage, String permission, PmCommand pmCommand) {
        this.targetPackage = shellEscape(targetPackage);
        this.permission = shellEscape(permission);
        this.command = pmCommand;
    }

    @Override // androidx.test.runner.permission.ShellCommand
    public void execute() throws Exception {
        executePermissionCommand(commandForPermission());
    }

    protected String commandForPermission() {
        return this.command.get() + " " + this.targetPackage + " " + this.permission;
    }

    private void executePermissionCommand(String cmd) throws IOException {
        String valueOf = String.valueOf(cmd);
        Log.i(TAG, valueOf.length() != 0 ? "Requesting permission: ".concat(valueOf) : new String("Requesting permission: "));
        try {
            awaitTermination(this.uiAutomation.executeShellCommand(cmd), 2L, TimeUnit.SECONDS);
        } catch (TimeoutException unused) {
            String valueOf2 = String.valueOf(cmd);
            Log.e(TAG, valueOf2.length() != 0 ? "Timeout while executing cmd: ".concat(valueOf2) : new String("Timeout while executing cmd: "));
        }
    }

    /* JADX WARN: Code restructure failed: missing block: B:13:0x0038, code lost:
        throw new java.util.concurrent.TimeoutException();
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private static void awaitTermination(ParcelFileDescriptor pfDescriptor, long timeout, TimeUnit unit) throws IOException, TimeoutException {
        long millis = unit.toMillis(timeout);
        long currentTimeMillis = millis > 0 ? System.currentTimeMillis() + millis : 0L;
        BufferedReader bufferedReader = null;
        try {
            BufferedReader bufferedReader2 = new BufferedReader(new InputStreamReader(new ParcelFileDescriptor.AutoCloseInputStream(pfDescriptor)));
            while (true) {
                try {
                    String readLine = bufferedReader2.readLine();
                    if (readLine != null) {
                        Log.i(TAG, readLine);
                        if (currentTimeMillis > System.currentTimeMillis()) {
                            break;
                        }
                    } else {
                        bufferedReader2.close();
                        return;
                    }
                } catch (Throwable th) {
                    th = th;
                    bufferedReader = bufferedReader2;
                    if (bufferedReader != null) {
                        bufferedReader.close();
                    }
                    throw th;
                }
            }
        } catch (Throwable th2) {
            th = th2;
        }
    }
}
