package com.hjq.gson.factory.element;

import com.google.gson.FieldNamingStrategy;
import com.google.gson.Gson;
import com.google.gson.TypeAdapter;
import com.google.gson.TypeAdapterFactory;
import com.google.gson.annotations.JsonAdapter;
import com.google.gson.annotations.SerializedName;
import com.google.gson.internal.ConstructorConstructor;
import com.google.gson.internal.Primitives;
import com.google.gson.reflect.TypeToken;
import com.google.gson.stream.JsonReader;
import com.google.gson.stream.JsonWriter;
import java.io.IOException;
import java.lang.reflect.Field;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.net.InetAddress;
import java.net.URI;
import java.net.URL;
import java.sql.Time;
import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.BitSet;
import java.util.Calendar;
import java.util.Currency;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.LinkedList;
import java.util.List;
import java.util.Locale;
import java.util.UUID;
import java.util.concurrent.atomic.AtomicBoolean;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.concurrent.atomic.AtomicIntegerArray;
import java.util.concurrent.atomic.AtomicLong;
import java.util.concurrent.atomic.AtomicLongArray;
/* loaded from: classes5.dex */
public class ReflectiveTypeUtils {
    private static final ArrayList<Class<?>> TYPE_TOKENS;

    static {
        ArrayList<Class<?>> arrayList = new ArrayList<>();
        TYPE_TOKENS = arrayList;
        arrayList.add(String.class);
        arrayList.add(Integer.class);
        arrayList.add(Boolean.class);
        arrayList.add(Byte.class);
        arrayList.add(Short.class);
        arrayList.add(Long.class);
        arrayList.add(Double.class);
        arrayList.add(Float.class);
        arrayList.add(Number.class);
        arrayList.add(AtomicInteger.class);
        arrayList.add(AtomicBoolean.class);
        arrayList.add(AtomicLong.class);
        arrayList.add(AtomicLongArray.class);
        arrayList.add(AtomicIntegerArray.class);
        arrayList.add(Character.class);
        arrayList.add(StringBuilder.class);
        arrayList.add(StringBuffer.class);
        arrayList.add(BigDecimal.class);
        arrayList.add(BigInteger.class);
        arrayList.add(URL.class);
        arrayList.add(URI.class);
        arrayList.add(UUID.class);
        arrayList.add(Currency.class);
        arrayList.add(Locale.class);
        arrayList.add(InetAddress.class);
        arrayList.add(BitSet.class);
        arrayList.add(Date.class);
        arrayList.add(GregorianCalendar.class);
        arrayList.add(Calendar.class);
        arrayList.add(Time.class);
        arrayList.add(java.sql.Date.class);
        arrayList.add(Timestamp.class);
        arrayList.add(Class.class);
    }

    public static boolean containsClass(Class<?> cls) {
        return TYPE_TOKENS.contains(cls);
    }

    public static ReflectiveFieldBound createBoundField(Gson gson, ConstructorConstructor constructorConstructor, Field field, String str, TypeToken<?> typeToken, boolean z, boolean z2) {
        return new ReflectiveFieldBound(str, z, z2, gson, constructorConstructor, field, typeToken, str, Primitives.isPrimitive(typeToken.getRawType())) { // from class: com.hjq.gson.factory.element.ReflectiveTypeUtils.1
            final TypeAdapter<?> typeAdapter;
            final /* synthetic */ ConstructorConstructor val$constructor;
            final /* synthetic */ Field val$field;
            final /* synthetic */ String val$fieldName;
            final /* synthetic */ TypeToken val$fieldType;
            final /* synthetic */ Gson val$gson;
            final /* synthetic */ boolean val$primitive;

            {
                this.val$gson = gson;
                this.val$constructor = constructorConstructor;
                this.val$field = field;
                this.val$fieldType = typeToken;
                this.val$fieldName = str;
                this.val$primitive = r9;
                this.typeAdapter = ReflectiveTypeUtils.getFieldAdapter(gson, constructorConstructor, field, typeToken, str);
            }

            @Override // com.hjq.gson.factory.element.ReflectiveFieldBound
            public void write(JsonWriter jsonWriter, Object obj) throws IOException, IllegalAccessException {
                new TypeAdapterRuntimeTypeWrapper(this.val$gson, this.typeAdapter, this.val$fieldType.getType()).write(jsonWriter, this.val$field.get(obj));
            }

            @Override // com.hjq.gson.factory.element.ReflectiveFieldBound
            public void read(JsonReader jsonReader, Object obj) throws IOException, IllegalAccessException {
                Object read = this.typeAdapter.read(jsonReader);
                if (read == null && this.val$primitive) {
                    return;
                }
                this.val$field.set(obj, read);
            }

            @Override // com.hjq.gson.factory.element.ReflectiveFieldBound
            public boolean writeField(Object obj) throws IOException, IllegalAccessException {
                return isSerialized() && this.val$field.get(obj) != obj;
            }
        };
    }

    public static TypeAdapter<?> getFieldAdapter(Gson gson, ConstructorConstructor constructorConstructor, Field field, TypeToken<?> typeToken, String str) {
        JsonAdapter jsonAdapter = (JsonAdapter) field.getAnnotation(JsonAdapter.class);
        TypeAdapter<?> typeAdapter = jsonAdapter != null ? getTypeAdapter(constructorConstructor, gson, typeToken, jsonAdapter) : null;
        if (typeAdapter == null) {
            typeAdapter = gson.getAdapter(typeToken);
        }
        if (typeAdapter instanceof CollectionTypeAdapter) {
            ((CollectionTypeAdapter) typeAdapter).setReflectiveType(TypeToken.get((Class) field.getDeclaringClass()), str);
        }
        if (typeAdapter instanceof ReflectiveTypeAdapter) {
            ((ReflectiveTypeAdapter) typeAdapter).setReflectiveType(TypeToken.get((Class) field.getDeclaringClass()), str);
        }
        if (typeAdapter instanceof MapTypeAdapter) {
            ((MapTypeAdapter) typeAdapter).setReflectiveType(TypeToken.get((Class) field.getDeclaringClass()), str);
        }
        return typeAdapter;
    }

    public static TypeAdapter<?> getTypeAdapter(ConstructorConstructor constructorConstructor, Gson gson, TypeToken<?> typeToken, JsonAdapter jsonAdapter) {
        TypeAdapter<?> create;
        Class<?> value = jsonAdapter.value();
        if (TypeAdapter.class.isAssignableFrom(value)) {
            create = (TypeAdapter) constructorConstructor.get(TypeToken.get((Class) value)).construct();
        } else if (TypeAdapterFactory.class.isAssignableFrom(value)) {
            create = ((TypeAdapterFactory) constructorConstructor.get(TypeToken.get((Class) value)).construct()).create(gson, typeToken);
        } else {
            throw new IllegalArgumentException("@JsonAdapter value must be TypeAdapter or TypeAdapterFactory reference.");
        }
        return create != null ? create.nullSafe() : create;
    }

    public static List<String> getFieldName(FieldNamingStrategy fieldNamingStrategy, Field field) {
        SerializedName serializedName = (SerializedName) field.getAnnotation(SerializedName.class);
        LinkedList linkedList = new LinkedList();
        if (serializedName == null) {
            linkedList.add(fieldNamingStrategy.translateName(field));
        } else {
            linkedList.add(serializedName.value());
            String[] alternate = serializedName.alternate();
            for (String str : alternate) {
                linkedList.add(str);
            }
        }
        return linkedList;
    }
}
