package com.hjq.http.body;

import com.hjq.http.EasyUtils;
import com.hjq.http.model.ContentType;
import java.io.IOException;
import java.util.Collection;
import java.util.List;
import java.util.Map;
import okhttp3.MediaType;
import okhttp3.RequestBody;
import okio.BufferedSink;
import org.json.JSONArray;
import org.json.JSONObject;
/* loaded from: classes6.dex */
public class JsonBody extends RequestBody {
    private final byte[] mBytes;
    private final String mJson;

    public JsonBody(Map<?, ?> map) {
        this(new JSONObject(map));
    }

    public JsonBody(List<?> list) {
        this(new JSONArray((Collection) list));
    }

    public JsonBody(JSONObject jSONObject) {
        String unescapeJson = EasyUtils.unescapeJson(jSONObject.toString());
        this.mJson = unescapeJson;
        this.mBytes = unescapeJson.getBytes();
    }

    public JsonBody(JSONArray jSONArray) {
        String unescapeJson = EasyUtils.unescapeJson(jSONArray.toString());
        this.mJson = unescapeJson;
        this.mBytes = unescapeJson.getBytes();
    }

    public JsonBody(String str) {
        this.mJson = str;
        this.mBytes = str.getBytes();
    }

    @Override // okhttp3.RequestBody
    public MediaType contentType() {
        return ContentType.JSON;
    }

    @Override // okhttp3.RequestBody
    public long contentLength() {
        return this.mBytes.length;
    }

    @Override // okhttp3.RequestBody
    public void writeTo(BufferedSink bufferedSink) throws IOException {
        byte[] bArr = this.mBytes;
        bufferedSink.write(bArr, 0, bArr.length);
    }

    public String toString() {
        return this.mJson;
    }

    public String getJson() {
        return this.mJson;
    }
}
