package com.hjq.http.callback;

import android.text.TextUtils;
import com.google.common.net.HttpHeaders;
import com.hjq.http.EasyLog;
import com.hjq.http.EasyUtils;
import com.hjq.http.config.IRequestInterceptor;
import com.hjq.http.exception.FileMD5Exception;
import com.hjq.http.exception.NullBodyException;
import com.hjq.http.exception.ResponseException;
import com.hjq.http.lifecycle.HttpLifecycleManager;
import com.hjq.http.listener.OnDownloadListener;
import com.hjq.http.request.HttpRequest;
import java.io.File;
import java.io.InputStream;
import java.io.OutputStream;
import okhttp3.Call;
import okhttp3.Response;
import okhttp3.ResponseBody;
/* loaded from: classes7.dex */
public final class DownloadCallback extends BaseCallback {
    private static final String FILE_MD5_REGEX = "^[\\w]{32}$";
    private long mDownloadByte;
    private int mDownloadProgress;
    private File mFile;
    private final HttpRequest<?> mHttpRequest;
    private OnDownloadListener mListener;
    private String mMd5;
    private long mTotalByte;

    public DownloadCallback(HttpRequest<?> httpRequest) {
        super(httpRequest);
        this.mHttpRequest = httpRequest;
    }

    public DownloadCallback setFile(File file) {
        this.mFile = file;
        return this;
    }

    public DownloadCallback setMd5(String str) {
        this.mMd5 = str;
        return this;
    }

    public DownloadCallback setListener(OnDownloadListener onDownloadListener) {
        this.mListener = onDownloadListener;
        return this;
    }

    @Override // com.hjq.http.callback.BaseCallback
    protected void onStart(Call call) {
        this.mHttpRequest.getRequestHandler().downloadStart(this.mHttpRequest, this.mFile);
        EasyUtils.runOnAssignThread(this.mHttpRequest.getThreadSchedulers(), new Runnable() { // from class: com.hjq.http.callback.DownloadCallback$$ExternalSyntheticLambda4
            @Override // java.lang.Runnable
            public final void run() {
                DownloadCallback.this.callOnStart();
            }
        });
    }

    @Override // com.hjq.http.callback.BaseCallback
    protected void onResponse(Response response) throws Exception {
        String header;
        EasyLog.printLog(this.mHttpRequest, "RequestConsuming：" + (response.receivedResponseAtMillis() - response.sentRequestAtMillis()) + " ms");
        IRequestInterceptor requestInterceptor = this.mHttpRequest.getRequestInterceptor();
        if (requestInterceptor != null) {
            response = requestInterceptor.interceptResponse(this.mHttpRequest, response);
        }
        if (!response.isSuccessful()) {
            throw new ResponseException("The request failed, responseCode: " + response.code() + ", message: " + response.message(), response);
        }
        if (this.mMd5 == null && (header = response.header(HttpHeaders.CONTENT_MD5)) != null && header.matches(FILE_MD5_REGEX)) {
            this.mMd5 = header;
        }
        File parentFile = this.mFile.getParentFile();
        if (parentFile != null) {
            EasyUtils.createFolder(parentFile);
        }
        ResponseBody body = response.body();
        if (body == null) {
            throw new NullBodyException("The response body is empty");
        }
        long contentLength = body.contentLength();
        this.mTotalByte = contentLength;
        if (contentLength < 0) {
            this.mTotalByte = 0L;
        }
        if (!TextUtils.isEmpty(this.mMd5) && this.mFile.isFile() && this.mMd5.equalsIgnoreCase(EasyUtils.getFileMd5(EasyUtils.openFileInputStream(this.mFile)))) {
            EasyLog.printLog(this.mHttpRequest, this.mFile.getPath() + " file already exists, skip download");
            EasyUtils.runOnAssignThread(this.mHttpRequest.getThreadSchedulers(), new Runnable() { // from class: com.hjq.http.callback.DownloadCallback$$ExternalSyntheticLambda0
                @Override // java.lang.Runnable
                public final void run() {
                    DownloadCallback.this.m350lambda$onResponse$0$comhjqhttpcallbackDownloadCallback();
                }
            });
            return;
        }
        this.mDownloadByte = 0L;
        byte[] bArr = new byte[8192];
        InputStream byteStream = body.byteStream();
        OutputStream openFileOutputStream = EasyUtils.openFileOutputStream(this.mFile);
        while (true) {
            int read = byteStream.read(bArr);
            if (read == -1) {
                break;
            }
            this.mDownloadByte += read;
            openFileOutputStream.write(bArr, 0, read);
            EasyUtils.runOnAssignThread(this.mHttpRequest.getThreadSchedulers(), new Runnable() { // from class: com.hjq.http.callback.DownloadCallback$$ExternalSyntheticLambda1
                @Override // java.lang.Runnable
                public final void run() {
                    DownloadCallback.this.callOnProgress();
                }
            });
        }
        EasyUtils.closeStream(byteStream);
        EasyUtils.closeStream(openFileOutputStream);
        String fileMd5 = EasyUtils.getFileMd5(EasyUtils.openFileInputStream(this.mFile));
        if (!TextUtils.isEmpty(this.mMd5) && !this.mMd5.equalsIgnoreCase(fileMd5)) {
            throw new FileMD5Exception("MD5 verify failure", fileMd5);
        }
        this.mHttpRequest.getRequestHandler().downloadSucceed(this.mHttpRequest, response, this.mFile);
        EasyLog.printLog(this.mHttpRequest, this.mFile.getPath() + " download completed");
        EasyUtils.runOnAssignThread(this.mHttpRequest.getThreadSchedulers(), new Runnable() { // from class: com.hjq.http.callback.DownloadCallback$$ExternalSyntheticLambda2
            @Override // java.lang.Runnable
            public final void run() {
                DownloadCallback.this.m351lambda$onResponse$1$comhjqhttpcallbackDownloadCallback();
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* renamed from: lambda$onResponse$0$com-hjq-http-callback-DownloadCallback  reason: not valid java name */
    public /* synthetic */ void m350lambda$onResponse$0$comhjqhttpcallbackDownloadCallback() {
        callOnComplete(true);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* renamed from: lambda$onResponse$1$com-hjq-http-callback-DownloadCallback  reason: not valid java name */
    public /* synthetic */ void m351lambda$onResponse$1$comhjqhttpcallbackDownloadCallback() {
        callOnComplete(false);
    }

    @Override // com.hjq.http.callback.BaseCallback
    protected void onFailure(Exception exc) {
        EasyLog.printThrowable(this.mHttpRequest, exc);
        final Exception downloadFail = this.mHttpRequest.getRequestHandler().downloadFail(this.mHttpRequest, exc);
        if (downloadFail != exc) {
            EasyLog.printThrowable(this.mHttpRequest, downloadFail);
        }
        HttpRequest<?> httpRequest = this.mHttpRequest;
        EasyLog.printLog(httpRequest, this.mFile.getPath() + " download error");
        EasyUtils.runOnAssignThread(this.mHttpRequest.getThreadSchedulers(), new Runnable() { // from class: com.hjq.http.callback.DownloadCallback$$ExternalSyntheticLambda3
            @Override // java.lang.Runnable
            public final void run() {
                DownloadCallback.this.m349lambda$onFailure$2$comhjqhttpcallbackDownloadCallback(downloadFail);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void callOnStart() {
        if (this.mListener == null || !HttpLifecycleManager.isLifecycleActive(this.mHttpRequest.getLifecycleOwner())) {
            return;
        }
        this.mListener.onStart(this.mFile);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void callOnProgress() {
        if (this.mListener == null || !HttpLifecycleManager.isLifecycleActive(this.mHttpRequest.getLifecycleOwner())) {
            return;
        }
        this.mListener.onByte(this.mFile, this.mTotalByte, this.mDownloadByte);
        int progressProgress = EasyUtils.getProgressProgress(this.mTotalByte, this.mDownloadByte);
        if (progressProgress != this.mDownloadProgress) {
            this.mDownloadProgress = progressProgress;
            this.mListener.onProgress(this.mFile, progressProgress);
            HttpRequest<?> httpRequest = this.mHttpRequest;
            EasyLog.printLog(httpRequest, this.mFile.getPath() + ", downloaded: " + this.mDownloadByte + " / " + this.mTotalByte + ", progress: " + progressProgress + " %");
        }
    }

    private void callOnComplete(boolean z) {
        if (this.mListener == null || !HttpLifecycleManager.isLifecycleActive(this.mHttpRequest.getLifecycleOwner())) {
            return;
        }
        this.mListener.onComplete(this.mFile, z);
        this.mListener.onEnd(this.mFile);
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: callOnError */
    public void m349lambda$onFailure$2$comhjqhttpcallbackDownloadCallback(Exception exc) {
        if (this.mListener == null || !HttpLifecycleManager.isLifecycleActive(this.mHttpRequest.getLifecycleOwner())) {
            return;
        }
        this.mListener.onError(this.mFile, exc);
        this.mListener.onEnd(this.mFile);
    }
}
