package com.hjq.http.callback;

import com.hjq.http.EasyLog;
import com.hjq.http.EasyUtils;
import com.hjq.http.config.IRequestHandler;
import com.hjq.http.config.IRequestInterceptor;
import com.hjq.http.lifecycle.HttpLifecycleManager;
import com.hjq.http.listener.OnHttpListener;
import com.hjq.http.model.CacheMode;
import com.hjq.http.request.HttpRequest;
import java.io.IOException;
import java.io.InputStream;
import java.lang.reflect.Type;
import okhttp3.Call;
import okhttp3.Response;
import okhttp3.ResponseBody;
/* loaded from: classes7.dex */
public final class NormalCallback extends BaseCallback {
    private final HttpRequest mHttpRequest;
    private OnHttpListener mListener;
    private Type mReflectType;

    public NormalCallback(HttpRequest httpRequest) {
        super(httpRequest);
        this.mHttpRequest = httpRequest;
    }

    public NormalCallback setListener(OnHttpListener onHttpListener) {
        this.mListener = onHttpListener;
        this.mReflectType = this.mHttpRequest.getRequestHandler().getType(this.mListener);
        return this;
    }

    @Override // com.hjq.http.callback.BaseCallback
    public void start() {
        CacheMode cacheMode = this.mHttpRequest.getRequestCache().getCacheMode();
        if (cacheMode != CacheMode.USE_CACHE_ONLY && cacheMode != CacheMode.USE_CACHE_FIRST) {
            super.start();
            return;
        }
        try {
            IRequestHandler requestHandler = this.mHttpRequest.getRequestHandler();
            HttpRequest<?> httpRequest = this.mHttpRequest;
            final Object readCache = requestHandler.readCache(httpRequest, this.mReflectType, httpRequest.getRequestCache().getCacheTime());
            HttpRequest httpRequest2 = this.mHttpRequest;
            EasyLog.printLog(httpRequest2, "ReadCache result：" + readCache);
            if (readCache == null) {
                super.start();
                return;
            }
            EasyUtils.runOnAssignThread(this.mHttpRequest.getThreadSchedulers(), new Runnable() { // from class: com.hjq.http.callback.NormalCallback$$ExternalSyntheticLambda0
                @Override // java.lang.Runnable
                public final void run() {
                    NormalCallback.this.m356lambda$start$0$comhjqhttpcallbackNormalCallback(readCache);
                }
            });
            if (cacheMode == CacheMode.USE_CACHE_FIRST) {
                EasyUtils.postDelayed(new Runnable() { // from class: com.hjq.http.callback.NormalCallback$$ExternalSyntheticLambda1
                    @Override // java.lang.Runnable
                    public final void run() {
                        NormalCallback.this.m357lambda$start$1$comhjqhttpcallbackNormalCallback();
                    }
                }, 1L);
            }
        } catch (Exception e) {
            EasyLog.printLog(this.mHttpRequest, "ReadCache error");
            EasyLog.printThrowable(this.mHttpRequest, e);
            super.start();
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* renamed from: lambda$start$0$com-hjq-http-callback-NormalCallback  reason: not valid java name */
    public /* synthetic */ void m356lambda$start$0$comhjqhttpcallbackNormalCallback(Object obj) {
        onStart(getCall());
        callOnSucceed(obj, true);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* renamed from: lambda$start$1$com-hjq-http-callback-NormalCallback  reason: not valid java name */
    public /* synthetic */ void m357lambda$start$1$comhjqhttpcallbackNormalCallback() {
        if (HttpLifecycleManager.isLifecycleActive(this.mHttpRequest.getLifecycleOwner())) {
            this.mListener = null;
            super.start();
        }
    }

    @Override // com.hjq.http.callback.BaseCallback
    protected void onStart(Call call) {
        EasyUtils.runOnAssignThread(this.mHttpRequest.getThreadSchedulers(), new Runnable() { // from class: com.hjq.http.callback.NormalCallback$$ExternalSyntheticLambda5
            @Override // java.lang.Runnable
            public final void run() {
                NormalCallback.this.callOnStart();
            }
        });
    }

    @Override // com.hjq.http.callback.BaseCallback
    protected void onResponse(Response response) throws Exception {
        HttpRequest httpRequest = this.mHttpRequest;
        EasyLog.printLog(httpRequest, "RequestConsuming：" + (response.receivedResponseAtMillis() - response.sentRequestAtMillis()) + " ms");
        IRequestInterceptor requestInterceptor = this.mHttpRequest.getRequestInterceptor();
        if (requestInterceptor != null) {
            response = requestInterceptor.interceptResponse(this.mHttpRequest, response);
        }
        final Object requestSuccess = this.mHttpRequest.getRequestHandler().requestSuccess(this.mHttpRequest, response, this.mReflectType);
        CacheMode cacheMode = this.mHttpRequest.getRequestCache().getCacheMode();
        if (cacheMode == CacheMode.USE_CACHE_ONLY || cacheMode == CacheMode.USE_CACHE_FIRST || cacheMode == CacheMode.USE_CACHE_AFTER_FAILURE) {
            try {
                boolean writeCache = this.mHttpRequest.getRequestHandler().writeCache(this.mHttpRequest, response, requestSuccess);
                HttpRequest httpRequest2 = this.mHttpRequest;
                EasyLog.printLog(httpRequest2, "WriteCache result：" + writeCache);
            } catch (Exception e) {
                EasyLog.printLog(this.mHttpRequest, "WriteCache error");
                EasyLog.printThrowable(this.mHttpRequest, e);
            }
        }
        EasyUtils.runOnAssignThread(this.mHttpRequest.getThreadSchedulers(), new Runnable() { // from class: com.hjq.http.callback.NormalCallback$$ExternalSyntheticLambda2
            @Override // java.lang.Runnable
            public final void run() {
                NormalCallback.this.m355lambda$onResponse$2$comhjqhttpcallbackNormalCallback(requestSuccess);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* renamed from: lambda$onResponse$2$com-hjq-http-callback-NormalCallback  reason: not valid java name */
    public /* synthetic */ void m355lambda$onResponse$2$comhjqhttpcallbackNormalCallback(Object obj) {
        callOnSucceed(obj, false);
    }

    @Override // com.hjq.http.callback.BaseCallback
    protected void onFailure(Exception exc) {
        EasyLog.printThrowable(this.mHttpRequest, exc);
        if ((exc instanceof IOException) && this.mHttpRequest.getRequestCache().getCacheMode() == CacheMode.USE_CACHE_AFTER_FAILURE) {
            try {
                IRequestHandler requestHandler = this.mHttpRequest.getRequestHandler();
                HttpRequest<?> httpRequest = this.mHttpRequest;
                final Object readCache = requestHandler.readCache(httpRequest, this.mReflectType, httpRequest.getRequestCache().getCacheTime());
                HttpRequest httpRequest2 = this.mHttpRequest;
                EasyLog.printLog(httpRequest2, "ReadCache result：" + readCache);
                if (readCache != null) {
                    EasyUtils.runOnAssignThread(this.mHttpRequest.getThreadSchedulers(), new Runnable() { // from class: com.hjq.http.callback.NormalCallback$$ExternalSyntheticLambda3
                        @Override // java.lang.Runnable
                        public final void run() {
                            NormalCallback.this.m353lambda$onFailure$3$comhjqhttpcallbackNormalCallback(readCache);
                        }
                    });
                    return;
                }
            } catch (Exception e) {
                EasyLog.printLog(this.mHttpRequest, "ReadCache error");
                EasyLog.printThrowable(this.mHttpRequest, e);
            }
        }
        final Exception requestFail = this.mHttpRequest.getRequestHandler().requestFail(this.mHttpRequest, exc);
        if (requestFail != exc) {
            EasyLog.printThrowable(this.mHttpRequest, requestFail);
        }
        EasyUtils.runOnAssignThread(this.mHttpRequest.getThreadSchedulers(), new Runnable() { // from class: com.hjq.http.callback.NormalCallback$$ExternalSyntheticLambda4
            @Override // java.lang.Runnable
            public final void run() {
                NormalCallback.this.m354lambda$onFailure$4$comhjqhttpcallbackNormalCallback(requestFail);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* renamed from: lambda$onFailure$3$com-hjq-http-callback-NormalCallback  reason: not valid java name */
    public /* synthetic */ void m353lambda$onFailure$3$comhjqhttpcallbackNormalCallback(Object obj) {
        callOnSucceed(obj, true);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void callOnStart() {
        if (this.mListener == null || !HttpLifecycleManager.isLifecycleActive(this.mHttpRequest.getLifecycleOwner())) {
            return;
        }
        this.mListener.onStart(getCall());
    }

    private void callOnSucceed(Object obj, boolean z) {
        if (this.mListener == null || !HttpLifecycleManager.isLifecycleActive(this.mHttpRequest.getLifecycleOwner())) {
            return;
        }
        this.mListener.onSucceed(obj, z);
        this.mListener.onEnd(getCall());
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: callOnFail */
    public void m354lambda$onFailure$4$comhjqhttpcallbackNormalCallback(Exception exc) {
        if (this.mListener == null || !HttpLifecycleManager.isLifecycleActive(this.mHttpRequest.getLifecycleOwner())) {
            return;
        }
        this.mListener.onFail(exc);
        this.mListener.onEnd(getCall());
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.hjq.http.callback.BaseCallback
    public void closeResponse(Response response) {
        if (Response.class.equals(this.mReflectType) || ResponseBody.class.equals(this.mReflectType) || InputStream.class.equals(this.mReflectType)) {
            return;
        }
        super.closeResponse(response);
    }
}
