package com.hjq.http.request;

import android.text.TextUtils;
import androidx.lifecycle.LifecycleOwner;
import com.hjq.http.EasyConfig;
import com.hjq.http.EasyLog;
import com.hjq.http.EasyUtils;
import com.hjq.http.body.CustomTypeBody;
import com.hjq.http.body.JsonBody;
import com.hjq.http.body.ProgressBody;
import com.hjq.http.body.TextBody;
import com.hjq.http.body.UpdateBody;
import com.hjq.http.listener.OnHttpListener;
import com.hjq.http.listener.OnUpdateListener;
import com.hjq.http.model.BodyType;
import com.hjq.http.model.FileContentResolver;
import com.hjq.http.model.HttpHeaders;
import com.hjq.http.model.HttpParams;
import com.hjq.http.request.BodyRequest;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.util.List;
import java.util.Map;
import okhttp3.FormBody;
import okhttp3.MediaType;
import okhttp3.MultipartBody;
import okhttp3.Request;
import okhttp3.RequestBody;
import okio.Okio;
/* loaded from: classes6.dex */
public abstract class BodyRequest<T extends BodyRequest<?>> extends HttpRequest<T> {
    private RequestBody mRequestBody;
    private OnUpdateListener<?> mUpdateListener;

    public BodyRequest(LifecycleOwner lifecycleOwner) {
        super(lifecycleOwner);
    }

    /* JADX WARN: Multi-variable type inference failed */
    public T json(Map<?, ?> map) {
        return map == null ? this : (T) body(new JsonBody(map));
    }

    /* JADX WARN: Multi-variable type inference failed */
    public T json(List<?> list) {
        return list == null ? this : (T) body(new JsonBody(list));
    }

    /* JADX WARN: Multi-variable type inference failed */
    public T json(String str) {
        return str == null ? this : (T) body(new JsonBody(str));
    }

    /* JADX WARN: Multi-variable type inference failed */
    public T text(String str) {
        return str == null ? this : (T) body(new TextBody(str));
    }

    /* JADX WARN: Multi-variable type inference failed */
    public T body(RequestBody requestBody) {
        this.mRequestBody = requestBody;
        return this;
    }

    @Override // com.hjq.http.request.HttpRequest
    public void request(OnHttpListener<?> onHttpListener) {
        if (onHttpListener instanceof OnUpdateListener) {
            this.mUpdateListener = (OnUpdateListener) onHttpListener;
        }
        if (this.mRequestBody != null) {
            this.mRequestBody = new ProgressBody(this, this.mRequestBody, getLifecycleOwner(), this.mUpdateListener);
        }
        super.request(onHttpListener);
    }

    /* renamed from: com.hjq.http.request.BodyRequest$1  reason: invalid class name */
    /* loaded from: classes5.dex */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$com$hjq$http$model$BodyType;

        static {
            int[] iArr = new int[BodyType.values().length];
            $SwitchMap$com$hjq$http$model$BodyType = iArr;
            try {
                iArr[BodyType.JSON.ordinal()] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                $SwitchMap$com$hjq$http$model$BodyType[BodyType.FORM.ordinal()] = 2;
            } catch (NoSuchFieldError unused2) {
            }
        }
    }

    @Override // com.hjq.http.request.HttpRequest
    protected void addHttpParams(HttpParams httpParams, String str, Object obj, BodyType bodyType) {
        if (AnonymousClass1.$SwitchMap$com$hjq$http$model$BodyType[bodyType.ordinal()] == 1) {
            httpParams.put(str, EasyUtils.convertObject(obj));
        } else {
            httpParams.put(str, obj);
        }
    }

    @Override // com.hjq.http.request.HttpRequest
    protected void addRequestParams(Request.Builder builder, HttpParams httpParams, String str, BodyType bodyType) {
        RequestBody requestBody = this.mRequestBody;
        if (requestBody == null) {
            requestBody = createRequestBody(httpParams, str, bodyType);
        }
        builder.method(getRequestMethod(), requestBody);
    }

    @Override // com.hjq.http.request.HttpRequest
    protected void printRequestLog(Request request, HttpParams httpParams, HttpHeaders httpHeaders, BodyType bodyType) {
        if (EasyConfig.getInstance().isLogEnabled()) {
            EasyLog.printKeyValue(this, "RequestUrl", String.valueOf(request.url()));
            EasyLog.printKeyValue(this, "RequestMethod", getRequestMethod());
            RequestBody body = request.body();
            if (!httpHeaders.isEmpty() || !httpParams.isEmpty()) {
                EasyLog.printLine(this);
            }
            for (String str : httpHeaders.getKeys()) {
                EasyLog.printKeyValue(this, str, httpHeaders.get(str));
            }
            if (!httpHeaders.isEmpty() && !httpParams.isEmpty()) {
                EasyLog.printLine(this);
            }
            RequestBody findRealRequestBody = EasyUtils.findRealRequestBody(body);
            if ((findRealRequestBody instanceof FormBody) || (findRealRequestBody instanceof MultipartBody)) {
                for (String str2 : httpParams.getKeys()) {
                    Object obj = httpParams.get(str2);
                    if (obj instanceof Map) {
                        Map map = (Map) obj;
                        for (Object obj2 : map.keySet()) {
                            if (obj2 != null) {
                                printKeyValue(String.valueOf(obj2), map.get(obj2));
                            }
                        }
                    } else if (obj instanceof List) {
                        List list = (List) obj;
                        for (int i = 0; i < list.size(); i++) {
                            Object obj3 = list.get(i);
                            printKeyValue(str2 + "[" + i + "]", obj3);
                        }
                    } else {
                        printKeyValue(str2, obj);
                    }
                }
            } else if (findRealRequestBody instanceof JsonBody) {
                EasyLog.printJson(this, String.valueOf(findRealRequestBody));
            } else if (findRealRequestBody instanceof TextBody) {
                EasyLog.printLog(this, String.valueOf(findRealRequestBody));
            } else if (findRealRequestBody != null) {
                EasyLog.printLog(this, String.valueOf(findRealRequestBody));
            }
            if (httpHeaders.isEmpty() && httpParams.isEmpty()) {
                return;
            }
            EasyLog.printLine(this);
        }
    }

    private RequestBody createRequestBody(HttpParams httpParams, String str, BodyType bodyType) {
        CustomTypeBody createFormBody;
        MediaType parse;
        if (httpParams.isMultipart() && !httpParams.isEmpty()) {
            createFormBody = createMultipartBody(httpParams);
        } else if (bodyType == BodyType.JSON) {
            createFormBody = createJsonBody(httpParams);
        } else {
            createFormBody = createFormBody(httpParams);
        }
        if (str != null && !"".equals(str) && (parse = MediaType.parse(str)) != null) {
            CustomTypeBody customTypeBody = new CustomTypeBody(createFormBody);
            customTypeBody.setContentType(parse);
            createFormBody = customTypeBody;
        }
        return this.mUpdateListener != null ? new ProgressBody(this, createFormBody, getLifecycleOwner(), this.mUpdateListener) : createFormBody;
    }

    private RequestBody createMultipartBody(HttpParams httpParams) {
        Object obj;
        MultipartBody.Builder builder = new MultipartBody.Builder();
        builder.setType(MultipartBody.FORM);
        for (String str : httpParams.getKeys()) {
            Object obj2 = httpParams.get(str);
            if (obj2 instanceof Map) {
                Map map = (Map) obj2;
                for (Object obj3 : map.keySet()) {
                    if (obj3 != null && (obj = map.get(obj3)) != null) {
                        addFormData(builder, String.valueOf(obj3), obj);
                    }
                }
            } else if (obj2 instanceof List) {
                for (Object obj4 : (List) obj2) {
                    if (obj4 != null) {
                        addFormData(builder, str, obj4);
                    }
                }
            } else {
                addFormData(builder, str, obj2);
            }
        }
        try {
            return builder.build();
        } catch (IllegalStateException unused) {
            return new FormBody.Builder().build();
        }
    }

    private RequestBody createJsonBody(HttpParams httpParams) {
        return new JsonBody(httpParams.getParams());
    }

    private RequestBody createFormBody(HttpParams httpParams) {
        FormBody.Builder builder = new FormBody.Builder();
        if (!httpParams.isEmpty()) {
            for (String str : httpParams.getKeys()) {
                Object obj = httpParams.get(str);
                if (!(obj instanceof List)) {
                    builder.add(str, String.valueOf(obj));
                } else {
                    for (Object obj2 : (List) obj) {
                        if (obj2 != null) {
                            builder.add(str, String.valueOf(obj2));
                        }
                    }
                }
            }
        }
        return builder.build();
    }

    private void addFormData(MultipartBody.Builder builder, String str, Object obj) {
        MultipartBody.Part createFormData;
        if (obj instanceof File) {
            File file = (File) obj;
            String fileName = file instanceof FileContentResolver ? ((FileContentResolver) file).getFileName() : null;
            if (TextUtils.isEmpty(fileName)) {
                fileName = file.getName();
            }
            try {
                if (file instanceof FileContentResolver) {
                    FileContentResolver fileContentResolver = (FileContentResolver) file;
                    InputStream openInputStream = fileContentResolver.openInputStream();
                    createFormData = MultipartBody.Part.createFormData(str, fileName, new UpdateBody(Okio.source(openInputStream), fileContentResolver.getContentType(), fileName, openInputStream.available()));
                } else {
                    createFormData = MultipartBody.Part.createFormData(str, fileName, new UpdateBody(file));
                }
                builder.addPart(createFormData);
            } catch (FileNotFoundException unused) {
                EasyLog.printLog(this, "File does not exist, will be ignored upload: " + str + " = " + file.getPath());
            } catch (IOException e) {
                EasyLog.printThrowable(this, e);
                EasyLog.printLog(this, "File stream reading failed and will be ignored upload: " + str + " = " + file.getPath());
            }
        } else if (obj instanceof InputStream) {
            try {
                builder.addPart(MultipartBody.Part.createFormData(str, null, new UpdateBody((InputStream) obj, str)));
            } catch (IOException e2) {
                EasyLog.printThrowable(this, e2);
            }
        } else if (obj instanceof RequestBody) {
            RequestBody requestBody = (RequestBody) obj;
            if (requestBody instanceof UpdateBody) {
                builder.addPart(MultipartBody.Part.createFormData(str, ((UpdateBody) requestBody).getKeyName(), requestBody));
            } else {
                builder.addPart(MultipartBody.Part.createFormData(str, null, requestBody));
            }
        } else if (obj instanceof MultipartBody.Part) {
            builder.addPart((MultipartBody.Part) obj);
        } else {
            builder.addFormDataPart(str, String.valueOf(obj));
        }
    }
}
