package com.tekartik.sqflite;

import java.util.HashMap;
import java.util.HashSet;
import java.util.LinkedList;
import java.util.ListIterator;
import java.util.Map;
import java.util.Set;
/* JADX INFO: Access modifiers changed from: package-private */
/* compiled from: DatabaseWorkerPool.java */
/* loaded from: classes7.dex */
public class DatabaseWorkerPoolImpl implements DatabaseWorkerPool {
    final String name;
    final int numberOfWorkers;
    final int priority;
    private final LinkedList<DatabaseTask> waitingList = new LinkedList<>();
    private final Set<DatabaseWorker> idleWorkers = new HashSet();
    private final Set<DatabaseWorker> busyWorkers = new HashSet();
    private final Map<Integer, DatabaseWorker> onlyEligibleWorkers = new HashMap();

    @Override // com.tekartik.sqflite.DatabaseWorkerPool
    public /* synthetic */ void post(Database database, Runnable runnable) {
        post(new DatabaseTask(r2 == null ? null : new DatabaseDelegate() { // from class: com.tekartik.sqflite.DatabaseWorkerPool.1
            @Override // com.tekartik.sqflite.DatabaseDelegate
            public int getDatabaseId() {
                return database.id;
            }

            @Override // com.tekartik.sqflite.DatabaseDelegate
            public boolean isInTransaction() {
                return database.isInTransaction();
            }
        }, runnable));
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public DatabaseWorkerPoolImpl(String str, int i, int i2) {
        this.name = str;
        this.numberOfWorkers = i;
        this.priority = i2;
    }

    @Override // com.tekartik.sqflite.DatabaseWorkerPool
    public synchronized void start() {
        for (int i = 0; i < this.numberOfWorkers; i++) {
            final DatabaseWorker createWorker = createWorker(this.name + i, this.priority);
            createWorker.start(new Runnable() { // from class: com.tekartik.sqflite.DatabaseWorkerPoolImpl$$ExternalSyntheticLambda0
                @Override // java.lang.Runnable
                public final void run() {
                    DatabaseWorkerPoolImpl.this.m368lambda$start$0$comtekartiksqfliteDatabaseWorkerPoolImpl(createWorker);
                }
            });
            this.idleWorkers.add(createWorker);
        }
    }

    protected DatabaseWorker createWorker(String str, int i) {
        return new DatabaseWorker(str, i);
    }

    @Override // com.tekartik.sqflite.DatabaseWorkerPool
    public synchronized void quit() {
        for (DatabaseWorker databaseWorker : this.idleWorkers) {
            databaseWorker.quit();
        }
        for (DatabaseWorker databaseWorker2 : this.busyWorkers) {
            databaseWorker2.quit();
        }
    }

    @Override // com.tekartik.sqflite.DatabaseWorkerPool
    public synchronized void post(DatabaseTask databaseTask) {
        this.waitingList.add(databaseTask);
        for (DatabaseWorker databaseWorker : new HashSet(this.idleWorkers)) {
            tryPostingTaskToWorker(databaseWorker);
        }
    }

    private synchronized void tryPostingTaskToWorker(DatabaseWorker databaseWorker) {
        DatabaseTask findTaskForWorker = findTaskForWorker(databaseWorker);
        if (findTaskForWorker != null) {
            this.busyWorkers.add(databaseWorker);
            this.idleWorkers.remove(databaseWorker);
            if (findTaskForWorker.getDatabaseId() != null) {
                this.onlyEligibleWorkers.put(findTaskForWorker.getDatabaseId(), databaseWorker);
            }
            databaseWorker.postTask(findTaskForWorker);
        }
    }

    /* JADX WARN: Code restructure failed: missing block: B:12:0x002b, code lost:
        r0.remove();
     */
    /* JADX WARN: Code restructure failed: missing block: B:14:0x002f, code lost:
        return r1;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private synchronized DatabaseTask findTaskForWorker(DatabaseWorker databaseWorker) {
        ListIterator<DatabaseTask> listIterator = this.waitingList.listIterator();
        while (true) {
            if (!listIterator.hasNext()) {
                return null;
            }
            DatabaseTask next = listIterator.next();
            DatabaseWorker databaseWorker2 = next.getDatabaseId() != null ? this.onlyEligibleWorkers.get(next.getDatabaseId()) : null;
            if (databaseWorker2 == null || databaseWorker2 == databaseWorker) {
                break;
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* renamed from: onWorkerIdle */
    public synchronized void m368lambda$start$0$comtekartiksqfliteDatabaseWorkerPoolImpl(DatabaseWorker databaseWorker) {
        HashSet<DatabaseWorker> hashSet = new HashSet(this.idleWorkers);
        this.busyWorkers.remove(databaseWorker);
        this.idleWorkers.add(databaseWorker);
        if (!databaseWorker.isLastTaskInTransaction() && databaseWorker.lastTaskDatabaseId() != null) {
            this.onlyEligibleWorkers.remove(databaseWorker.lastTaskDatabaseId());
        }
        tryPostingTaskToWorker(databaseWorker);
        for (DatabaseWorker databaseWorker2 : hashSet) {
            tryPostingTaskToWorker(databaseWorker2);
        }
    }
}
