package dev.fluttercommunity.plus.connectivity;

import android.net.ConnectivityManager;
import android.net.NetworkCapabilities;
import android.net.NetworkInfo;
import android.os.Build;
/* loaded from: classes5.dex */
public class Connectivity {
    static final String CONNECTIVITY_BLUETOOTH = "bluetooth";
    static final String CONNECTIVITY_ETHERNET = "ethernet";
    static final String CONNECTIVITY_MOBILE = "mobile";
    static final String CONNECTIVITY_NONE = "none";
    static final String CONNECTIVITY_VPN = "vpn";
    static final String CONNECTIVITY_WIFI = "wifi";
    private final ConnectivityManager connectivityManager;

    public Connectivity(ConnectivityManager connectivityManager) {
        this.connectivityManager = connectivityManager;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public String getNetworkType() {
        if (Build.VERSION.SDK_INT >= 23) {
            NetworkCapabilities networkCapabilities = this.connectivityManager.getNetworkCapabilities(this.connectivityManager.getActiveNetwork());
            if (networkCapabilities == null) {
                return "none";
            }
            if (networkCapabilities.hasTransport(1)) {
                return CONNECTIVITY_WIFI;
            }
            if (networkCapabilities.hasTransport(3)) {
                return CONNECTIVITY_ETHERNET;
            }
            if (networkCapabilities.hasTransport(4)) {
                return CONNECTIVITY_VPN;
            }
            if (networkCapabilities.hasTransport(0)) {
                return CONNECTIVITY_MOBILE;
            }
            if (networkCapabilities.hasTransport(2)) {
                return CONNECTIVITY_BLUETOOTH;
            }
        }
        return getNetworkTypeLegacy();
    }

    private String getNetworkTypeLegacy() {
        NetworkInfo activeNetworkInfo = this.connectivityManager.getActiveNetworkInfo();
        if (activeNetworkInfo == null || !activeNetworkInfo.isConnected()) {
            return "none";
        }
        int type = activeNetworkInfo.getType();
        return type != 0 ? type != 1 ? (type == 4 || type == 5) ? CONNECTIVITY_MOBILE : type != 6 ? type != 7 ? type != 9 ? type != 17 ? "none" : CONNECTIVITY_VPN : CONNECTIVITY_ETHERNET : CONNECTIVITY_BLUETOOTH : CONNECTIVITY_WIFI : CONNECTIVITY_WIFI : CONNECTIVITY_MOBILE;
    }

    public ConnectivityManager getConnectivityManager() {
        return this.connectivityManager;
    }
}
