package io.flutter.plugins.imagepicker;

import android.content.Context;
import android.database.Cursor;
import android.net.Uri;
import android.webkit.MimeTypeMap;
import io.flutter.Log;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.UUID;
/* loaded from: classes5.dex */
class FileUtils {
    /* JADX INFO: Access modifiers changed from: package-private */
    public String getPathFromUri(Context context, Uri uri) {
        try {
            InputStream openInputStream = context.getContentResolver().openInputStream(uri);
            File file = new File(context.getCacheDir(), UUID.randomUUID().toString());
            file.mkdir();
            file.deleteOnExit();
            String imageName = getImageName(context, uri);
            String imageExtension = getImageExtension(context, uri);
            if (imageName == null) {
                Log.w("FileUtils", "Cannot get file name for " + uri);
                if (imageExtension == null) {
                    imageExtension = ".jpg";
                }
                imageName = "image_picker" + imageExtension;
            } else if (imageExtension != null) {
                imageName = getBaseName(imageName) + imageExtension;
            }
            File file2 = new File(file, imageName);
            FileOutputStream fileOutputStream = new FileOutputStream(file2);
            copy(openInputStream, fileOutputStream);
            String path = file2.getPath();
            fileOutputStream.close();
            if (openInputStream != null) {
                openInputStream.close();
            }
            return path;
        } catch (IOException | SecurityException unused) {
            return null;
        }
    }

    private static String getImageExtension(Context context, Uri uri) {
        String fileExtensionFromUrl;
        try {
            if (uri.getScheme().equals("content")) {
                fileExtensionFromUrl = MimeTypeMap.getSingleton().getExtensionFromMimeType(context.getContentResolver().getType(uri));
            } else {
                fileExtensionFromUrl = MimeTypeMap.getFileExtensionFromUrl(Uri.fromFile(new File(uri.getPath())).toString());
            }
            if (fileExtensionFromUrl != null && !fileExtensionFromUrl.isEmpty()) {
                return "." + fileExtensionFromUrl;
            }
        } catch (Exception unused) {
        }
        return null;
    }

    /* JADX WARN: Code restructure failed: missing block: B:21:0x002d, code lost:
        r1.close();
     */
    /* JADX WARN: Code restructure failed: missing block: B:22:0x0030, code lost:
        return null;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private static String getImageName(Context context, Uri uri) {
        Cursor queryImageName = queryImageName(context, uri);
        if (queryImageName != null) {
            try {
                if (queryImageName.moveToFirst() && queryImageName.getColumnCount() >= 1) {
                    String string = queryImageName.getString(0);
                    if (queryImageName != null) {
                        queryImageName.close();
                    }
                    return string;
                }
            } catch (Throwable th) {
                if (queryImageName != null) {
                    try {
                        queryImageName.close();
                    } catch (Throwable th2) {
                        th.addSuppressed(th2);
                    }
                }
                throw th;
            }
        }
        return null;
    }

    private static Cursor queryImageName(Context context, Uri uri) {
        return context.getContentResolver().query(uri, new String[]{"_display_name"}, null, null, null);
    }

    private static void copy(InputStream inputStream, OutputStream outputStream) throws IOException {
        byte[] bArr = new byte[4096];
        while (true) {
            int read = inputStream.read(bArr);
            if (read != -1) {
                outputStream.write(bArr, 0, read);
            } else {
                outputStream.flush();
                return;
            }
        }
    }

    private static String getBaseName(String str) {
        int lastIndexOf = str.lastIndexOf(46);
        return lastIndexOf < 0 ? str : str.substring(0, lastIndexOf);
    }
}
